==> spirit_hub-1.0.0.5.tar.gz: spirit_hub-1.0.0.5/spec/models/pdf/annotation/base_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'

class DummyAnnotation < SpiritHub::Pdf::Annotation::Base
  def annotation_type
    'dummy'
  end
end

RSpec.describe SpiritHub::Pdf::Annotation::Base, type: :model do
  let(:doc) { create(:doc) }

  describe 'validations' do
    it 'validates presence of page_index' do
      annotation = DummyAnnotation.new(content: 'Test content', position_data: { 'rect' => [0, 0, 100, 100] })
      expect(annotation).not_to be_valid
      expect(annotation.errors[:page_index]).not_to be_empty
    end
  end

  describe '#to_frontend_json' do
    it 'returns a hash with the expected keys and values' do
      annotation = DummyAnnotation.new(page_index: 2,
                                       content: 'Sample content',
                                       position_data: { 'rect' => [10, 10, 50, 50] },
                                       style_data: { 'color' => 'blue' })
      annotation.doc = doc
      annotation.save!
      frontend_json = annotation.to_frontend_json
      expect(frontend_json).to eq({
                                    id: annotation.id.to_s,
                                    pageIndex: 2,
                                    rect: [10, 10, 50, 50],
                                    value: 'Sample content',
                                    annotationType: 'dummy'
                                  })
    end
  end

  describe '#annotation_type' do
    it 'raises NotImplementedError in the base class' do
      base_annotation = SpiritHub::Pdf::Annotation::Base.new(page_index: 1, content: 'Test', position_data: {})
      base_annotation.doc = doc
      expect { base_annotation.annotation_type }.to raise_error(NotImplementedError)
    end
  end
end

==> spirit_hub-1.0.0.11.tar.gz: spirit_hub-1.0.0.11/spec/models/pdf/annotation/base_spec.rb <==
# frozen_string_literal: true

require 'rails_helper'

class DummyAnnotation < SpiritHub::Pdf::Annotation::Base
  def annotation_type
    'dummy'
  end
end

RSpec.describe SpiritHub::Pdf::Annotation::Base, type: :model do
  let(:doc) { create(:doc) }

  describe 'validations' do
    it 'validates presence of page_index' do
      annotation = DummyAnnotation.new(content: 'Test content', position_data: { 'rect' => [0, 0, 100, 100] })
      expect(annotation).not_to be_valid
      expect(annotation.errors[:page_index]).not_to be_empty
    end
  end

  describe '#to_frontend_json' do
    it 'returns a hash with the expected keys and values' do
      annotation = DummyAnnotation.new(page_index: 2,
                                       content: 'Sample content',
                                       position_data: { 'rect' => [10, 10, 50, 50] },
                                       style_data: { 'color' => 'blue' })
      annotation.doc = doc
      annotation.save!
      frontend_json = annotation.to_frontend_json
      expect(frontend_json).to eq({
                                    id: annotation.id.to_s,
                                    pageIndex: 2,
                                    rect: [10, 10, 50, 50],
                                    value: 'Sample content',
                                    annotationType: 'dummy',
                                    user_picture_url: nil
                                  })
    end
  end

  describe '#annotation_type' do
    it 'raises NotImplementedError in the base class' do
      base_annotation = SpiritHub::Pdf::Annotation::Base.new(page_index: 1, content: 'Test', position_data: {})
      base_annotation.doc = doc
      expect { base_annotation.annotation_type }.to raise_error(NotImplementedError)
    end
  end
end
